summaryrefslogtreecommitdiff
path: root/gcc/common/config
diff options
context:
space:
mode:
authorbstarynk <bstarynk@138bc75d-0d04-0410-961f-82ee72b054a4>2014-01-04 17:57:29 +0000
committerbstarynk <bstarynk@138bc75d-0d04-0410-961f-82ee72b054a4>2014-01-04 17:57:29 +0000
commit48ff1d417d4c49525c09b013395e38dda8bd50fe (patch)
treeffb4ea05f14bc936b5dd3681e19b2aa3cee8c3bf /gcc/common/config
parent144409bbbdb293946cea105115e0e329f633d333 (diff)
downloadgcc-48ff1d417d4c49525c09b013395e38dda8bd50fe.tar.gz
2014-01-04 Basile Starynkevitch <basile@starynkevitch.net>
{{merge using svnmerge.py with trunk GCC 4.9 svn rev206333 now in stage 3; very unstable, xtramelt-ana-base don't compile anymore...}} git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/branches/melt-branch@206336 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/common/config')
-rw-r--r--gcc/common/config/aarch64/aarch64-common.c37
-rw-r--r--gcc/common/config/alpha/alpha-common.c2
-rw-r--r--gcc/common/config/arc/arc-common.c3
-rw-r--r--gcc/common/config/arm/arm-common.c37
-rw-r--r--gcc/common/config/avr/avr-common.c2
-rw-r--r--gcc/common/config/bfin/bfin-common.c2
-rw-r--r--gcc/common/config/c6x/c6x-common.c2
-rw-r--r--gcc/common/config/cr16/cr16-common.c2
-rw-r--r--gcc/common/config/cris/cris-common.c2
-rw-r--r--gcc/common/config/default-common.c2
-rw-r--r--gcc/common/config/epiphany/epiphany-common.c2
-rw-r--r--gcc/common/config/fr30/fr30-common.c2
-rw-r--r--gcc/common/config/frv/frv-common.c2
-rw-r--r--gcc/common/config/h8300/h8300-common.c2
-rw-r--r--gcc/common/config/i386/i386-common.c20
-rw-r--r--gcc/common/config/ia64/ia64-common.c2
-rw-r--r--gcc/common/config/iq2000/iq2000-common.c2
-rw-r--r--gcc/common/config/lm32/lm32-common.c2
-rw-r--r--gcc/common/config/m32r/m32r-common.c2
-rw-r--r--gcc/common/config/m68k/m68k-common.c2
-rw-r--r--gcc/common/config/mcore/mcore-common.c2
-rw-r--r--gcc/common/config/mep/mep-common.c2
-rw-r--r--gcc/common/config/microblaze/microblaze-common.c2
-rw-r--r--gcc/common/config/mips/mips-common.c2
-rw-r--r--gcc/common/config/mmix/mmix-common.c2
-rw-r--r--gcc/common/config/mn10300/mn10300-common.c2
-rw-r--r--gcc/common/config/nds32/nds32-common.c15
-rw-r--r--gcc/common/config/nios2/nios2-common.c44
-rw-r--r--gcc/common/config/pa/pa-common.c2
-rw-r--r--gcc/common/config/pdp11/pdp11-common.c2
-rw-r--r--gcc/common/config/picochip/picochip-common.c2
-rw-r--r--gcc/common/config/rs6000/rs6000-common.c2
-rw-r--r--gcc/common/config/rx/rx-common.c2
-rw-r--r--gcc/common/config/s390/s390-common.c2
-rw-r--r--gcc/common/config/score/score-common.c2
-rw-r--r--gcc/common/config/sh/sh-common.c3
-rw-r--r--gcc/common/config/sparc/sparc-common.c2
-rw-r--r--gcc/common/config/spu/spu-common.c2
-rw-r--r--gcc/common/config/tilegx/tilegx-common.c2
-rw-r--r--gcc/common/config/tilepro/tilepro-common.c2
-rw-r--r--gcc/common/config/v850/v850-common.c2
-rw-r--r--gcc/common/config/vax/vax-common.c2
-rw-r--r--gcc/common/config/xstormy16/xstormy16-common.c2
-rw-r--r--gcc/common/config/xtensa/xtensa-common.c2
44 files changed, 185 insertions, 48 deletions
diff --git a/gcc/common/config/aarch64/aarch64-common.c b/gcc/common/config/aarch64/aarch64-common.c
index 9c8e7705109..135a9bcbdd2 100644
--- a/gcc/common/config/aarch64/aarch64-common.c
+++ b/gcc/common/config/aarch64/aarch64-common.c
@@ -1,5 +1,5 @@
/* Common hooks for AArch64.
- Copyright (C) 2012-2013 Free Software Foundation, Inc.
+ Copyright (C) 2012-2014 Free Software Foundation, Inc.
Contributed by ARM Ltd.
This file is part of GCC.
@@ -88,3 +88,38 @@ aarch64_handle_option (struct gcc_options *opts,
}
struct gcc_targetm_common targetm_common = TARGETM_COMMON_INITIALIZER;
+
+#define AARCH64_CPU_NAME_LENGTH 20
+
+/* Truncate NAME at the first '.' character seen, or return
+ NAME unmodified. */
+
+const char *
+aarch64_rewrite_selected_cpu (const char *name)
+{
+ static char output_buf[AARCH64_CPU_NAME_LENGTH + 1] = {0};
+ char *arg_pos;
+
+ strncpy (output_buf, name, AARCH64_CPU_NAME_LENGTH);
+ arg_pos = strchr (output_buf, '.');
+
+ /* If we found a '.' truncate the entry at that point. */
+ if (arg_pos)
+ *arg_pos = '\0';
+
+ return output_buf;
+}
+
+/* Called by the driver to rewrite a name passed to the -mcpu
+ argument in preparation to be passed to the assembler. The
+ name will be in ARGV[0], ARGC should always be 1. */
+
+const char *
+aarch64_rewrite_mcpu (int argc, const char **argv)
+{
+ gcc_assert (argc == 1);
+ return aarch64_rewrite_selected_cpu (argv[0]);
+}
+
+#undef AARCH64_CPU_NAME_LENGTH
+
diff --git a/gcc/common/config/alpha/alpha-common.c b/gcc/common/config/alpha/alpha-common.c
index a0c2a6baec4..a103bb8b436 100644
--- a/gcc/common/config/alpha/alpha-common.c
+++ b/gcc/common/config/alpha/alpha-common.c
@@ -1,5 +1,5 @@
/* Common hooks for DEC Alpha.
- Copyright (C) 1992-2013 Free Software Foundation, Inc.
+ Copyright (C) 1992-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/arc/arc-common.c b/gcc/common/config/arc/arc-common.c
index 36e60ebc9d8..03986806a7e 100644
--- a/gcc/common/config/arc/arc-common.c
+++ b/gcc/common/config/arc/arc-common.c
@@ -1,6 +1,5 @@
/* Common hooks for Synopsys DesignWare ARC
- Copyright (C) 1994, 1995, 1997, 1998, 2007-2013
- Free Software Foundation, Inc.
+ Copyright (C) 1994-2014 Free Software Foundation, Inc.
Contributor: Joern Rennecke <joern.rennecke@embecosm.com>
on behalf of Synopsys Inc.
diff --git a/gcc/common/config/arm/arm-common.c b/gcc/common/config/arm/arm-common.c
index c43a2ce927b..065de7d8d0a 100644
--- a/gcc/common/config/arm/arm-common.c
+++ b/gcc/common/config/arm/arm-common.c
@@ -1,5 +1,5 @@
/* Common hooks for ARM.
- Copyright (C) 1991-2013 Free Software Foundation, Inc.
+ Copyright (C) 1991-2014 Free Software Foundation, Inc.
This file is part of GCC.
@@ -63,6 +63,41 @@ arm_except_unwind_info (struct gcc_options *opts)
return UI_SJLJ;
}
+#define ARM_CPU_NAME_LENGTH 20
+
+/* Truncate NAME at the first '.' character seen, or return
+ NAME unmodified. */
+
+const char *
+arm_rewrite_selected_cpu (const char *name)
+{
+ static char output_buf[ARM_CPU_NAME_LENGTH + 1] = {0};
+ char *arg_pos;
+
+ strncpy (output_buf, name, ARM_CPU_NAME_LENGTH);
+ arg_pos = strchr (output_buf, '.');
+
+ /* If we found a '.' truncate the entry at that point. */
+ if (arg_pos)
+ *arg_pos = '\0';
+
+ return output_buf;
+}
+
+/* Called by the driver to rewrite a name passed to the -mcpu
+ argument in preparation to be passed to the assembler. The
+ name will be in ARGV[0], ARGC should always be 1. */
+
+const char *
+arm_rewrite_mcpu (int argc, const char **argv)
+{
+ gcc_assert (argc == 1);
+ return arm_rewrite_selected_cpu (argv[0]);
+}
+
+#undef ARM_CPU_NAME_LENGTH
+
+
#undef TARGET_DEFAULT_TARGET_FLAGS
#define TARGET_DEFAULT_TARGET_FLAGS (TARGET_DEFAULT | MASK_SCHED_PROLOG)
diff --git a/gcc/common/config/avr/avr-common.c b/gcc/common/config/avr/avr-common.c
index f485de70b6f..231ed57a160 100644
--- a/gcc/common/config/avr/avr-common.c
+++ b/gcc/common/config/avr/avr-common.c
@@ -1,5 +1,5 @@
/* Common hooks for ATMEL AVR.
- Copyright (C) 1998-2013 Free Software Foundation, Inc.
+ Copyright (C) 1998-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/bfin/bfin-common.c b/gcc/common/config/bfin/bfin-common.c
index 8859c88e8e3..65edc2f54a1 100644
--- a/gcc/common/config/bfin/bfin-common.c
+++ b/gcc/common/config/bfin/bfin-common.c
@@ -1,5 +1,5 @@
/* Common hooks for Blackfin.
- Copyright (C) 2005-2013 Free Software Foundation, Inc.
+ Copyright (C) 2005-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/c6x/c6x-common.c b/gcc/common/config/c6x/c6x-common.c
index ee982910d27..8547a71bdf8 100644
--- a/gcc/common/config/c6x/c6x-common.c
+++ b/gcc/common/config/c6x/c6x-common.c
@@ -1,5 +1,5 @@
/* TI C6X common hooks.
- Copyright (C) 2011-2013 Free Software Foundation, Inc.
+ Copyright (C) 2011-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/cr16/cr16-common.c b/gcc/common/config/cr16/cr16-common.c
index 33fb9405565..2317216f978 100644
--- a/gcc/common/config/cr16/cr16-common.c
+++ b/gcc/common/config/cr16/cr16-common.c
@@ -1,5 +1,5 @@
/* Common hooks for CR16.
- Copyright (C) 2012-2013 Free Software Foundation, Inc.
+ Copyright (C) 2012-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/cris/cris-common.c b/gcc/common/config/cris/cris-common.c
index 1cd186555dc..d605ac69b40 100644
--- a/gcc/common/config/cris/cris-common.c
+++ b/gcc/common/config/cris/cris-common.c
@@ -1,5 +1,5 @@
/* Common hooks for CRIS.
- Copyright (C) 1998-2013 Free Software Foundation, Inc.
+ Copyright (C) 1998-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/default-common.c b/gcc/common/config/default-common.c
index 6c8f505d0db..d2424fdc380 100644
--- a/gcc/common/config/default-common.c
+++ b/gcc/common/config/default-common.c
@@ -1,5 +1,5 @@
/* Default common target hooks initializer.
- Copyright (C) 2011-2013 Free Software Foundation, Inc.
+ Copyright (C) 2011-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/epiphany/epiphany-common.c b/gcc/common/config/epiphany/epiphany-common.c
index 291a7fca352..725dfb8356d 100644
--- a/gcc/common/config/epiphany/epiphany-common.c
+++ b/gcc/common/config/epiphany/epiphany-common.c
@@ -1,5 +1,5 @@
/* Common hooks for Adapteva Epiphany
- Copyright (C) 1994-2013 Free Software Foundation, Inc.
+ Copyright (C) 1994-2014 Free Software Foundation, Inc.
Contributed by Embecosm on behalf of Adapteva, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/fr30/fr30-common.c b/gcc/common/config/fr30/fr30-common.c
index 1f46d824919..ade8705e519 100644
--- a/gcc/common/config/fr30/fr30-common.c
+++ b/gcc/common/config/fr30/fr30-common.c
@@ -1,5 +1,5 @@
/* Common hooks for FR30.
- Copyright (C) 1998-2013 Free Software Foundation, Inc.
+ Copyright (C) 1998-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/frv/frv-common.c b/gcc/common/config/frv/frv-common.c
index d196f8de3d4..1b4fe3726cf 100644
--- a/gcc/common/config/frv/frv-common.c
+++ b/gcc/common/config/frv/frv-common.c
@@ -1,4 +1,4 @@
-/* Copyright (C) 1997-2013 Free Software Foundation, Inc.
+/* Copyright (C) 1997-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/h8300/h8300-common.c b/gcc/common/config/h8300/h8300-common.c
index 0dd1a5c4b01..01a9092426a 100644
--- a/gcc/common/config/h8300/h8300-common.c
+++ b/gcc/common/config/h8300/h8300-common.c
@@ -1,5 +1,5 @@
/* Common hooks for Renesas H8/300.
- Copyright (C) 1992-2013 Free Software Foundation, Inc.
+ Copyright (C) 1992-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/ia64/ia64-common.c b/gcc/common/config/ia64/ia64-common.c
index 677ca4529d1..44cfa316af2 100644
--- a/gcc/common/config/ia64/ia64-common.c
+++ b/gcc/common/config/ia64/ia64-common.c
@@ -1,5 +1,5 @@
/* Common hooks for IA64.
- Copyright (C) 1999-2013 Free Software Foundation, Inc.
+ Copyright (C) 1999-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/iq2000/iq2000-common.c b/gcc/common/config/iq2000/iq2000-common.c
index f660ac587c9..4644a2b1602 100644
--- a/gcc/common/config/iq2000/iq2000-common.c
+++ b/gcc/common/config/iq2000/iq2000-common.c
@@ -1,5 +1,5 @@
/* Common hooks for Vitesse IQ2000.
- Copyright (C) 2003-2013 Free Software Foundation, Inc.
+ Copyright (C) 2003-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/lm32/lm32-common.c b/gcc/common/config/lm32/lm32-common.c
index df78e6b86d0..a4839431491 100644
--- a/gcc/common/config/lm32/lm32-common.c
+++ b/gcc/common/config/lm32/lm32-common.c
@@ -1,6 +1,6 @@
/* Common hooks for Lattice Mico32.
- Copyright (C) 2009-2013 Free Software Foundation, Inc.
+ Copyright (C) 2009-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/m32r/m32r-common.c b/gcc/common/config/m32r/m32r-common.c
index f8df5a847fd..4e5f1352a58 100644
--- a/gcc/common/config/m32r/m32r-common.c
+++ b/gcc/common/config/m32r/m32r-common.c
@@ -1,5 +1,5 @@
/* Common hooks for Renesas M32R.
- Copyright (C) 1996-2013 Free Software Foundation, Inc.
+ Copyright (C) 1996-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/m68k/m68k-common.c b/gcc/common/config/m68k/m68k-common.c
index 0c95f405cbc..6db1f8bc9a7 100644
--- a/gcc/common/config/m68k/m68k-common.c
+++ b/gcc/common/config/m68k/m68k-common.c
@@ -1,5 +1,5 @@
/* Common hooks for Motorola 68000 family.
- Copyright (C) 1987-2013 Free Software Foundation, Inc.
+ Copyright (C) 1987-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/mcore/mcore-common.c b/gcc/common/config/mcore/mcore-common.c
index 11e50f3028b..bbdcb59d715 100644
--- a/gcc/common/config/mcore/mcore-common.c
+++ b/gcc/common/config/mcore/mcore-common.c
@@ -1,5 +1,5 @@
/* Common hooks for Motorola MCore.
- Copyright (C) 1993-2013 Free Software Foundation, Inc.
+ Copyright (C) 1993-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/mep/mep-common.c b/gcc/common/config/mep/mep-common.c
index a6376831a2a..5c2bd803104 100644
--- a/gcc/common/config/mep/mep-common.c
+++ b/gcc/common/config/mep/mep-common.c
@@ -1,5 +1,5 @@
/* Common hooks for Toshiba Media Processor.
- Copyright (C) 2001-2013 Free Software Foundation, Inc.
+ Copyright (C) 2001-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/microblaze/microblaze-common.c b/gcc/common/config/microblaze/microblaze-common.c
index 07a71fb0025..108c040427f 100644
--- a/gcc/common/config/microblaze/microblaze-common.c
+++ b/gcc/common/config/microblaze/microblaze-common.c
@@ -1,5 +1,5 @@
/* Common hooks for Xilinx MicroBlaze.
- Copyright (C) 2009-2013 Free Software Foundation, Inc.
+ Copyright (C) 2009-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/mips/mips-common.c b/gcc/common/config/mips/mips-common.c
index b9de63da877..cece4ae3b65 100644
--- a/gcc/common/config/mips/mips-common.c
+++ b/gcc/common/config/mips/mips-common.c
@@ -1,5 +1,5 @@
/* Common hooks for MIPS.
- Copyright (C) 1989-2013 Free Software Foundation, Inc.
+ Copyright (C) 1989-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/mmix/mmix-common.c b/gcc/common/config/mmix/mmix-common.c
index 54acb4d892b..fe1fba25be6 100644
--- a/gcc/common/config/mmix/mmix-common.c
+++ b/gcc/common/config/mmix/mmix-common.c
@@ -1,5 +1,5 @@
/* Common hooks for MMIX.
- Copyright (C) 2000-2013 Free Software Foundation, Inc.
+ Copyright (C) 2000-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/mn10300/mn10300-common.c b/gcc/common/config/mn10300/mn10300-common.c
index 0a03d66c5d5..e1226f20fcb 100644
--- a/gcc/common/config/mn10300/mn10300-common.c
+++ b/gcc/common/config/mn10300/mn10300-common.c
@@ -1,5 +1,5 @@
/* Common hooks for Matsushita MN10300 series.
- Copyright (C) 1996-2013 Free Software Foundation, Inc.
+ Copyright (C) 1996-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/nds32/nds32-common.c b/gcc/common/config/nds32/nds32-common.c
index f82f725af14..7d9bf6704b1 100644
--- a/gcc/common/config/nds32/nds32-common.c
+++ b/gcc/common/config/nds32/nds32-common.c
@@ -1,5 +1,5 @@
/* Common hooks of Andes NDS32 cpu for GNU compiler
- Copyright (C) 2012-2013 Free Software Foundation, Inc.
+ Copyright (C) 2012-2014 Free Software Foundation, Inc.
Contributed by Andes Technology Corporation.
This file is part of GCC.
@@ -86,14 +86,23 @@ static const struct default_options nds32_option_optimization_table[] =
/* Run-time Target Specification. */
-/* Default enable
+/* The default target flags consist of
+ TARGET_CPU_DEFAULT and other MASK_XXX flags.
+
+ The value of TARGET_CPU_DEFAULT is set by
+ the process of 'configure' and 'make' stage.
+ Please check gcc/config.gcc for more implementation detail.
+
+ Other MASK_XXX flags are set individually.
+ By default we enable
TARGET_GP_DIRECT: Generate gp-imply instruction.
TARGET_16_BIT : Generate 16/32 bit mixed length instruction.
TARGET_PERF_EXT : Generate performance extention instrcution.
TARGET_CMOV : Generate conditional move instruction. */
#undef TARGET_DEFAULT_TARGET_FLAGS
#define TARGET_DEFAULT_TARGET_FLAGS \
- (MASK_GP_DIRECT \
+ (TARGET_CPU_DEFAULT \
+ | MASK_GP_DIRECT \
| MASK_16_BIT \
| MASK_PERF_EXT \
| MASK_CMOV)
diff --git a/gcc/common/config/nios2/nios2-common.c b/gcc/common/config/nios2/nios2-common.c
new file mode 100644
index 00000000000..333591a979c
--- /dev/null
+++ b/gcc/common/config/nios2/nios2-common.c
@@ -0,0 +1,44 @@
+/* Common hooks for Altera Nios II.
+ Copyright (C) 2012-2014 Free Software Foundation, Inc.
+
+This file is part of GCC.
+
+GCC is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3, or (at your option)
+any later version.
+
+GCC is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with GCC; see the file COPYING3. If not see
+<http://www.gnu.org/licenses/>. */
+
+#include "config.h"
+#include "system.h"
+#include "coretypes.h"
+#include "diagnostic-core.h"
+#include "tm.h"
+#include "common/common-target.h"
+#include "common/common-target-def.h"
+#include "opts.h"
+#include "flags.h"
+
+/* Implement TARGET_OPTION_OPTIMIZATION_TABLE. */
+static const struct default_options nios2_option_optimization_table[] =
+ {
+ { OPT_LEVELS_1_PLUS, OPT_fomit_frame_pointer, NULL, 1 },
+ { OPT_LEVELS_3_PLUS, OPT_mfast_sw_div, NULL, 1 },
+ { OPT_LEVELS_NONE, 0, NULL, 0 }
+ };
+
+#undef TARGET_DEFAULT_TARGET_FLAGS
+#define TARGET_DEFAULT_TARGET_FLAGS TARGET_DEFAULT
+
+#undef TARGET_OPTION_OPTIMIZATION_TABLE
+#define TARGET_OPTION_OPTIMIZATION_TABLE nios2_option_optimization_table
+
+struct gcc_targetm_common targetm_common = TARGETM_COMMON_INITIALIZER;
diff --git a/gcc/common/config/pa/pa-common.c b/gcc/common/config/pa/pa-common.c
index e61b8ca944a..3ada756628c 100644
--- a/gcc/common/config/pa/pa-common.c
+++ b/gcc/common/config/pa/pa-common.c
@@ -1,5 +1,5 @@
/* HPPA common hooks.
- Copyright (C) 1992-2013 Free Software Foundation, Inc.
+ Copyright (C) 1992-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/pdp11/pdp11-common.c b/gcc/common/config/pdp11/pdp11-common.c
index 4cc32bfd826..3ad5a1fee59 100644
--- a/gcc/common/config/pdp11/pdp11-common.c
+++ b/gcc/common/config/pdp11/pdp11-common.c
@@ -1,5 +1,5 @@
/* Common hooks for pdp11.
- Copyright (C) 1994-2013 Free Software Foundation, Inc.
+ Copyright (C) 1994-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/picochip/picochip-common.c b/gcc/common/config/picochip/picochip-common.c
index 09c8ff50593..e6fdccfa98a 100644
--- a/gcc/common/config/picochip/picochip-common.c
+++ b/gcc/common/config/picochip/picochip-common.c
@@ -1,5 +1,5 @@
/* Common hooks for picoChip.
- Copyright (C) 2001-2013 Free Software Foundation, Inc.
+ Copyright (C) 2001-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/rs6000/rs6000-common.c b/gcc/common/config/rs6000/rs6000-common.c
index 8ec43f10935..a3df590aa8a 100644
--- a/gcc/common/config/rs6000/rs6000-common.c
+++ b/gcc/common/config/rs6000/rs6000-common.c
@@ -1,5 +1,5 @@
/* Common hooks for IBM RS/6000.
- Copyright (C) 1991-2013 Free Software Foundation, Inc.
+ Copyright (C) 1991-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/rx/rx-common.c b/gcc/common/config/rx/rx-common.c
index 4186148318e..7a35b09b04f 100644
--- a/gcc/common/config/rx/rx-common.c
+++ b/gcc/common/config/rx/rx-common.c
@@ -1,5 +1,5 @@
/* Common hooks for Renesas RX.
- Copyright (C) 2008-2013 Free Software Foundation, Inc.
+ Copyright (C) 2008-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/s390/s390-common.c b/gcc/common/config/s390/s390-common.c
index c2031b74b1f..b65a71fb545 100644
--- a/gcc/common/config/s390/s390-common.c
+++ b/gcc/common/config/s390/s390-common.c
@@ -1,5 +1,5 @@
/* Common hooks for IBM S/390 and zSeries.
- Copyright (C) 1999-2013 Free Software Foundation, Inc.
+ Copyright (C) 1999-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/score/score-common.c b/gcc/common/config/score/score-common.c
index b3769879101..51bd9553ae4 100644
--- a/gcc/common/config/score/score-common.c
+++ b/gcc/common/config/score/score-common.c
@@ -1,5 +1,5 @@
/* Common hooks for Sunplus S+CORE.
- Copyright (C) 2005-2013 Free Software Foundation, Inc.
+ Copyright (C) 2005-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/sh/sh-common.c b/gcc/common/config/sh/sh-common.c
index f7fb9f5641c..70663f48f84 100644
--- a/gcc/common/config/sh/sh-common.c
+++ b/gcc/common/config/sh/sh-common.c
@@ -1,5 +1,5 @@
/* Common hooks for Renesas / SuperH SH.
- Copyright (C) 1993-2013 Free Software Foundation, Inc.
+ Copyright (C) 1993-2014 Free Software Foundation, Inc.
This file is part of GCC.
@@ -34,7 +34,6 @@ static const struct default_options sh_option_optimization_table[] =
{ OPT_LEVELS_1_PLUS_SPEED_ONLY, OPT_mdiv_, "inv:minlat", 1 },
{ OPT_LEVELS_SIZE, OPT_mdiv_, SH_DIV_STR_FOR_SIZE, 1 },
{ OPT_LEVELS_0_ONLY, OPT_mdiv_, "", 1 },
- { OPT_LEVELS_SIZE, OPT_mcbranchdi, NULL, 0 },
/* We can't meaningfully test TARGET_SHMEDIA here, because -m
options haven't been parsed yet, hence we'd read only the
default. sh_target_reg_class will return NO_REGS if this is
diff --git a/gcc/common/config/sparc/sparc-common.c b/gcc/common/config/sparc/sparc-common.c
index 14bfbfd0cb2..a2af6c11740 100644
--- a/gcc/common/config/sparc/sparc-common.c
+++ b/gcc/common/config/sparc/sparc-common.c
@@ -1,5 +1,5 @@
/* Common hooks for SPARC.
- Copyright (C) 1987-2013 Free Software Foundation, Inc.
+ Copyright (C) 1987-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/spu/spu-common.c b/gcc/common/config/spu/spu-common.c
index 71beacf9c15..d622925f7dc 100644
--- a/gcc/common/config/spu/spu-common.c
+++ b/gcc/common/config/spu/spu-common.c
@@ -1,5 +1,5 @@
/* Common hooks for SPU.
- Copyright (C) 2006-2013 Free Software Foundation, Inc.
+ Copyright (C) 2006-2014 Free Software Foundation, Inc.
This file is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
diff --git a/gcc/common/config/tilegx/tilegx-common.c b/gcc/common/config/tilegx/tilegx-common.c
index a16d58d06cd..6294f7ddcda 100644
--- a/gcc/common/config/tilegx/tilegx-common.c
+++ b/gcc/common/config/tilegx/tilegx-common.c
@@ -1,5 +1,5 @@
/* Common hooks for TILE-Gx.
- Copyright (C) 2011-2013 Free Software Foundation, Inc.
+ Copyright (C) 2011-2014 Free Software Foundation, Inc.
Contributed by Walter Lee (walt@tilera.com)
This file is part of GCC.
diff --git a/gcc/common/config/tilepro/tilepro-common.c b/gcc/common/config/tilepro/tilepro-common.c
index dc7ea978e40..a9604aefba6 100644
--- a/gcc/common/config/tilepro/tilepro-common.c
+++ b/gcc/common/config/tilepro/tilepro-common.c
@@ -1,5 +1,5 @@
/* Common hooks for TILEPro.
- Copyright (C) 2011-2013 Free Software Foundation, Inc.
+ Copyright (C) 2011-2014 Free Software Foundation, Inc.
Contributed by Walter Lee (walt@tilera.com)
This file is part of GCC.
diff --git a/gcc/common/config/v850/v850-common.c b/gcc/common/config/v850/v850-common.c
index c5035aefb60..a59d1dff3f9 100644
--- a/gcc/common/config/v850/v850-common.c
+++ b/gcc/common/config/v850/v850-common.c
@@ -1,5 +1,5 @@
/* Common hooks for NEC V850 series.
- Copyright (C) 1996-2013 Free Software Foundation, Inc.
+ Copyright (C) 1996-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/vax/vax-common.c b/gcc/common/config/vax/vax-common.c
index 6b48e6661e4..921ce841d26 100644
--- a/gcc/common/config/vax/vax-common.c
+++ b/gcc/common/config/vax/vax-common.c
@@ -1,5 +1,5 @@
/* Common hooks for VAX.
- Copyright (C) 1987-2013 Free Software Foundation, Inc.
+ Copyright (C) 1987-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/xstormy16/xstormy16-common.c b/gcc/common/config/xstormy16/xstormy16-common.c
index e89ea739b1b..aee3a388328 100644
--- a/gcc/common/config/xstormy16/xstormy16-common.c
+++ b/gcc/common/config/xstormy16/xstormy16-common.c
@@ -1,5 +1,5 @@
/* Common hooks for Xstormy16.
- Copyright (C) 1997-2013 Free Software Foundation, Inc.
+ Copyright (C) 1997-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/xtensa/xtensa-common.c b/gcc/common/config/xtensa/xtensa-common.c
index 39c036a678d..f5f200a66b8 100644
--- a/gcc/common/config/xtensa/xtensa-common.c
+++ b/gcc/common/config/xtensa/xtensa-common.c
@@ -1,5 +1,5 @@
/* Common hooks for Tensilica's Xtensa architecture.
- Copyright (C) 2001-2013 Free Software Foundation, Inc.
+ Copyright (C) 2001-2014 Free Software Foundation, Inc.
This file is part of GCC.
diff --git a/gcc/common/config/i386/i386-common.c b/gcc/common/config/i386/i386-common.c
index e07479da28c..b7f9ff6b642 100644
--- a/gcc/common/config/i386/i386-common.c
+++ b/gcc/common/config/i386/i386-common.c
@@ -1,5 +1,5 @@
/* IA-32 common hooks.
- Copyright (C) 1988-2013 Free Software Foundation, Inc.
+ Copyright (C) 1988-2014 Free Software Foundation, Inc.
This file is part of GCC.
@@ -84,9 +84,11 @@ along with GCC; see the file COPYING3. If not see
#define OPTION_MASK_ISA_LWP_SET \
OPTION_MASK_ISA_LWP
/* AES and PCLMUL need SSE2 because they use xmm registers */
#define OPTION_MASK_ISA_AES_SET \
(OPTION_MASK_ISA_AES | OPTION_MASK_ISA_SSE2_SET)
+#define OPTION_MASK_ISA_SHA_SET \
+ (OPTION_MASK_ISA_SHA | OPTION_MASK_ISA_SSE2_SET)
#define OPTION_MASK_ISA_PCLMUL_SET \
(OPTION_MASK_ISA_PCLMUL | OPTION_MASK_ISA_SSE2_SET)
@@ -166,6 +168,7 @@ along with GCC; see the file COPYING3. If not see
#define OPTION_MASK_ISA_LWP_UNSET OPTION_MASK_ISA_LWP
#define OPTION_MASK_ISA_AES_UNSET OPTION_MASK_ISA_AES
+#define OPTION_MASK_ISA_SHA_UNSET OPTION_MASK_ISA_SHA
#define OPTION_MASK_ISA_PCLMUL_UNSET OPTION_MASK_ISA_PCLMUL
#define OPTION_MASK_ISA_ABM_UNSET OPTION_MASK_ISA_ABM
#define OPTION_MASK_ISA_BMI_UNSET OPTION_MASK_ISA_BMI
@@ -611,6 +614,19 @@ ix86_handle_option (struct gcc_options *opts,
}
return true;
+ case OPT_msha:
+ if (value)
+ {
+ opts->x_ix86_isa_flags |= OPTION_MASK_ISA_SHA_SET;
+ opts->x_ix86_isa_flags_explicit |= OPTION_MASK_ISA_SHA_SET;
+ }
+ else
+ {
+ opts->x_ix86_isa_flags &= ~OPTION_MASK_ISA_SHA_UNSET;
+ opts->x_ix86_isa_flags_explicit |= OPTION_MASK_ISA_SHA_UNSET;
+ }
+ return true;
+
case OPT_mpclmul:
if (value)
{
@@ -84,9 +84,11 @@ along with GCC; see the file COPYING3. If not see
#define OPTION_MASK_ISA_LWP_SET \
OPTION_MASK_ISA_LWP
-/* AES and PCLMUL need SSE2 because they use xmm registers */
+/* AES, SHA and PCLMUL need SSE2 because they use xmm registers. */
#define OPTION_MASK_ISA_AES_SET \
(OPTION_MASK_ISA_AES | OPTION_MASK_ISA_SSE2_SET)